# PyIRCIoT

IRC-IoT is the universal protocol for building Internet of things (IoT)

More info about IRC-IoT protocol you can find at http://irc-iot.org/?lang=en

PyIRCIoT is a demonstration library for the implementation of the
functions of the IRC-IoT protocol

There is also a project for porting this library to Java:
 https://github.com/Markatrafik/JavaIRCIoT

